@@ -10,13 +10,21 @@ import types
 
 from . import validators
 
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 
 # constants for DeletionPolicy
 Delete = 'Delete'
 Retain = 'Retain'
 Snapshot = 'Snapshot'
 
+# Pseudo Parameters
+AWS_ACCOUNT_ID = 'AWS::AccountId'
+AWS_NOTIFICATION_ARNS = 'AWS::NotificationARNs'
+AWS_NO_VALUE = 'AWS::NoValue'
+AWS_REGION = 'AWS::Region'
+AWS_STACK_ID = 'AWS::StackId'
+AWS_STACK_NAME = 'AWS::StackName'
+
 valid_names = re.compile(r'^[a-zA-Z0-9]+$')
 
 
@@ -111,8 +119,9 @@ class BaseAWSObject(object):
             else:
                 self._raise_type(name, value, expected_type)
 
+        type_name = getattr(self, 'type', self.__class__.__name__)
         raise AttributeError("%s object does not support attribute %s" %
-                             (self.type, name))
+                             (type_name, name))
 
     def _raise_type(self, name, value, expected_type):
         raise TypeError('%s is %s, expected %s' %
@@ -131,8 +140,10 @@ class BaseAWSObject(object):
         # Mainly used to not have an empty "Properties".
         if self.properties:
             return self.resource
-        else:
+        elif hasattr(self, 'type'):
             return {'Type': self.type}
+        else:
+            return {}
 
 
 class AWSObject(BaseAWSObject):
@@ -253,7 +264,7 @@ class And(AWSHelperFn):
 
 class Or(AWSHelperFn):
     def __init__(self, cond_one, cond_two, *conds):
-        self.data = {'Fn::Or': [cond_two, cond_two] + list(conds)}
+        self.data = {'Fn::Or': [cond_one, cond_two] + list(conds)}
 
     def JSONrepr(self):
         return self.data
