@@ -3,7 +3,7 @@
 #
 # See LICENSE file for full license.
 
-from . import AWSObject
+from . import AWSObject, AWSProperty
 from .validators import integer
 try:
     from awacs.aws import Policy
@@ -12,6 +12,13 @@ except ImportError:
     policytypes = dict,
 
 
+class RedrivePolicy(AWSProperty):
+    props = {
+        'deadLetterTargetArn': (basestring, False),
+        'maxReceiveCount': (integer, False),
+    }
+
+
 class Queue(AWSObject):
     type = "AWS::SQS::Queue"
 
@@ -21,6 +28,7 @@ class Queue(AWSObject):
         'MessageRetentionPeriod': (integer, False),
         'QueueName': (basestring, False),
         'ReceiveMessageWaitTimeSeconds': (integer, False),
+        'RedrivePolicy': (RedrivePolicy, False),
         'VisibilityTimeout': (integer, False),
     }
 
